==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebHeaderTypeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebHeaderTypeDescription } from "./WebHeaderTypeDescription";
/**
 * @hidden
 */
export let WebHeaderTypeDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebHeaderTypeDescriptionMetadata extends Base {
        static b(a) {
            if (WebHeaderTypeDescriptionMetadata.a == null) {
                WebHeaderTypeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebHeaderTypeDescriptionMetadata.c(WebHeaderTypeDescriptionMetadata.a);
            }
            if (a.j(WebHeaderTypeDescriptionMetadata.a)) {
                return;
            }
            a.y(WebHeaderTypeDescriptionMetadata.a);
            WebColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:HeaderType");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Column", "ExportedType:WebColumn");
            a.item("Density", "ExportedType:string:DisplayDensity");
            a.item("Density@names", "Comfortable;Cosy;Compact");
            a.item("Sorted", "Boolean");
            a.item("Selectable", "Boolean");
            a.item("Selected", "Boolean");
            a.item("Title", "Boolean");
            a.item("SortDirection", "ExportedType:string:SortingDirection");
            a.item("SortDirection@names", "None;Asc;Desc");
        }
        static d(a) {
            WebHeaderTypeDescriptionMetadata.b(a);
            a.aa("WebHeaderType", () => new WebHeaderTypeDescription());
            a.z("WebHeaderType", WebHeaderTypeDescriptionMetadata.a);
        }
    }
    WebHeaderTypeDescriptionMetadata.$t = /*@__PURE__*/ markType(WebHeaderTypeDescriptionMetadata, 'WebHeaderTypeDescriptionMetadata');
    WebHeaderTypeDescriptionMetadata.a = null;
    return WebHeaderTypeDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebHeaderTypeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebHeaderTypeDescription } from "./WebHeaderTypeDescription";
/**
 * @hidden
 */
export let WebHeaderTypeDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebHeaderTypeDescriptionMetadata extends Base {
        static b(a) {
            if (WebHeaderTypeDescriptionMetadata.a == null) {
                WebHeaderTypeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebHeaderTypeDescriptionMetadata.c(WebHeaderTypeDescriptionMetadata.a);
            }
            if (a.k(WebHeaderTypeDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebHeaderTypeDescriptionMetadata.a);
            WebColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:HeaderType");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Column", "ExportedType:WebColumn");
            a.item("Density", "ExportedType:string:DisplayDensity");
            a.item("Density@stringUnion", "WebComponents;React");
            a.item("Density@names", "Comfortable;Cosy;Compact");
            a.item("Sorted", "Boolean");
            a.item("Selectable", "Boolean");
            a.item("Selected", "Boolean");
            a.item("Title", "Boolean");
            a.item("SortDirection", "ExportedType:string:SortingDirection");
            a.item("SortDirection@names", "None;Asc;Desc");
        }
        static d(a) {
            WebHeaderTypeDescriptionMetadata.b(a);
            a.ac("WebHeaderType", () => new WebHeaderTypeDescription());
            a.ab("WebHeaderType", WebHeaderTypeDescriptionMetadata.a);
        }
    }
    WebHeaderTypeDescriptionMetadata.$t = /*@__PURE__*/ markType(WebHeaderTypeDescriptionMetadata, 'WebHeaderTypeDescriptionMetadata');
    WebHeaderTypeDescriptionMetadata.a = null;
    return WebHeaderTypeDescriptionMetadata;
})();
